#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-aeson
version:              2.3.1.1
visibility:           public
id:                   hslua-aeson-2.3.1.1-EbPktR2iJ26Jro41eRR26c
key:                  hslua-aeson-2.3.1.1-EbPktR2iJ26Jro41eRR26c
license:              MIT
copyright:            © 2017–2024 Albert Krewinkel
maintainer:           Albert Krewinkel <tarleb@hslua.org>
author:               Albert Krewinkel
homepage:             https://hslua.org/
synopsis:             Allow aeson data types to be used with Lua.
description:
    This package provides instances to push and receive any
    datatype encodable as JSON to and from the Lua stack.

category:             Foreign
abi:                  fc2f9bf2c3f84ae07eb4244a42fc8888
exposed:              True
exposed-modules:      HsLua.Aeson
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-aeson-2.3.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-aeson
hs-libraries:         HShslua-aeson-2.3.1.1-EbPktR2iJ26Jro41eRR26c
depends:
    aeson-2.2.2.0-3wIqYzgVLxh1lGuh6CHfOQ base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    hashable-1.4.7.0-LW11JqjzVD83xeTPITysTC
    hslua-core-2.3.2-CwsNsASzqbpILrbT9FRlcq
    hslua-marshalling-2.3.1-LPGdviX2WonEDQDRO9DTGF mtl-2.3.1
    scientific-0.3.8.1-9XG2AQ4sh0vL0ppOZ1hCCJ text-2.0.2
    unordered-containers-0.2.20.1-HCJacsgu3yzJSt2gCXir1U
    vector-0.13.2.0-5aTe1V6fRGRBDLXlEcUVda

haddock-interfaces:   /usr/share/doc/haskell-hslua-aeson/html/hslua-aeson.haddock
haddock-html:         /usr/share/doc/haskell-hslua-aeson/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

